@@ -857,7 +857,7 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
 @_with_func_attrs(df_required_columns=['ObjectPropertyId', 'InstallationId', 'Timestamp', 'Value'])
 def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time: bool = True,
                       save_additional_columns_as_slices: bool = False, data_feed_file_status_id: uuid.UUID = None, 
-                      is_specific_timezone: Union[bool, str] = False):
+                      is_specific_timezone: Union[bool, str] = False, ingestion_mode: IngestionMode = 'Queued'):
     """Upserts timeseries to EventHub for processing.
 
     The following columns are required to be present in the data_frame:
@@ -1118,13 +1118,13 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
                                     'TimestampLocalId', 'Value', 'DataFeedFileStatusId', 'InstallationId', 'Meta']]
 
     container = 'data-ingestion-timeseries-adx'
-    folder = 'to-eventhub'
+    folder = 'to-adx-stream' if ingestion_mode == 'Stream' else 'to-eventhub'
     name = 'Timeseries'
     
     logger.info(f'Data frame size: {convert_bytes(data_frame.memory_usage(deep=True).sum())}')
     upload_result = Blob.upload(api_inputs=api_inputs, data_frame=data_frame, container=container, folder=folder, name=name, batch_id=data_feed_file_status_id, include_header=True)
 
-    json_payload = {"path": upload_result[0], "fileCount": upload_result[1]}
+    json_payload = {"path": upload_result[0], "fileCount": upload_result[1], "ingestionMode": ingestion_mode}
 
     url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/timeseries"
     logger.info("Sending request: POST %s", url)
